=head1 NAME

Acme::PodOnly::NoVersion - A Pod file with no version in provides

=head1 DESCRIPTION

This is a Pod file which is included in the distribution provides data, but
without a version being specified.

=head1 AUTHORS

See L<Acme::PodOnly> for authors.

=head1 COPYRIGHT AND LICENSE

See L<Acme::PodOnly> for the copyright and license.

=cut
